org.combinators.ep.language.java

Members list

Type members

Classlikes

sealed abstract class BoxLevel(val inMethods: Boolean, val inClasses: Boolean, val inConstructors: Boolean)

Attributes

Supertypes
class Object
trait Matchable
class Any
Known subtypes
object FullyBoxed
object Unboxed
case class ClassCtxt(resolver: ContextSpecificResolver, cls: ClassOrInterfaceDeclaration, extraImports: Seq[default.Import])

Attributes

Supertypes
trait Serializable
trait Product
trait Equals
class Object
trait Matchable
class Any
Show all
class CodeGenerator(config: Config)

Java-specific.

Java-specific.

These paradigm-specific traits are conceptually different from each other

Attributes

Companion
object
Supertypes
class Object
trait Matchable
class Any
Self type
object CodeGenerator

Attributes

Companion
class
Supertypes
class Object
trait Matchable
class Any
Self type
case class CompilationUnitCtxt(resolver: ContextSpecificResolver, unit: CompilationUnit, isTest: Boolean)

Attributes

Supertypes
trait Serializable
trait Product
trait Equals
class Object
trait Matchable
class Any
Show all
case class Config(targetPackage: PackageDeclaration, projectName: Option[String], boxLevel: BoxLevel)

Attributes

Supertypes
trait Serializable
trait Product
trait Equals
class Object
trait Matchable
class Any
Show all
case class ContextSpecificResolver(_methodTypeResolution: ContextSpecificResolver => TypeRep => Generator[MethodBodyCtxt, default.Type], _constructorTypeResolution: ContextSpecificResolver => TypeRep => Generator[CtorCtxt, default.Type], _classTypeResolution: ContextSpecificResolver => TypeRep => Generator[ClassCtxt, default.Type], _reificationInConstructor: ContextSpecificResolver => InstanceRep => Generator[CtorCtxt, default.Expression], _reificationInMethod: ContextSpecificResolver => InstanceRep => Generator[MethodBodyCtxt, default.Expression], _importResolution: ContextSpecificResolver => default.Type => Option[default.Import], _instantiationOverride: ContextSpecificResolver => (default.Type, Seq[default.Expression]) => (default.Type, Seq[default.Expression]), generatedVariables: Map[String, MangledName], resolverInfo: Set[Any] = ...)

Attributes

Companion
object
Supertypes
trait Serializable
trait Product
trait Equals
class Object
trait Matchable
class Any
Show all

Attributes

Companion
class
Supertypes
trait Product
trait Mirror
class Object
trait Matchable
class Any
Self type
case class CtorCtxt(resolver: ContextSpecificResolver, extraImports: Seq[default.Import], ctor: ConstructorDeclaration)

Attributes

Supertypes
trait Serializable
trait Product
trait Equals
class Object
trait Matchable
class Any
Show all
object ExitSBT

Attributes

Supertypes
class Object
trait Matchable
class Any
Self type
ExitSBT.type
class FreshNameCleanup(nameInfo: Map[String, MangledName])

Attributes

Companion
object
Supertypes
class Object
trait Matchable
class Any

Attributes

Companion
class
Supertypes
class Object
trait Matchable
class Any
Self type
case object FullyBoxed extends BoxLevel

Attributes

Supertypes
trait Singleton
trait Product
trait Mirror
trait Serializable
trait Product
trait Equals
class BoxLevel
class Object
trait Matchable
class Any
Show all
Self type
FullyBoxed.type

Attributes

Companion
object
Supertypes
class Object
trait Matchable
class Any
object ImportCleanup

Attributes

Companion
class
Supertypes
class Object
trait Matchable
class Any
Self type
object JavaNameProvider extends NameProvider[MangledName]

Provides name mangling for Java

Provides name mangling for Java

Attributes

Supertypes
class NameProvider[MangledName]
class Object
trait Matchable
class Any
Self type
case class MethodBodyCtxt(resolver: ContextSpecificResolver, extraImports: Seq[default.Import], method: MethodDeclaration)

Attributes

Supertypes
trait Serializable
trait Product
trait Equals
class Object
trait Matchable
class Any
Show all
object OperatorExprs

Operator Expressions are enclosed with parens (EnclosedExpr) to ensure correctness, even though this might lead to extra parens. These could always be filtered out later by a simplifier.

Operator Expressions are enclosed with parens (EnclosedExpr) to ensure correctness, even though this might lead to extra parens. These could always be filtered out later by a simplifier.

Attributes

Supertypes
class Object
trait Matchable
class Any
Self type
case object PartiallyBoxed extends BoxLevel

Attributes

Supertypes
trait Singleton
trait Product
trait Mirror
trait Serializable
trait Product
trait Equals
class BoxLevel
class Object
trait Matchable
class Any
Show all
Self type
case class ProjectCtxt(resolver: ContextSpecificResolver, units: Seq[CompilationUnit], testUnits: Seq[CompilationUnit], extraDependencies: Seq[String], customFiles: Seq[FileWithPath])

Attributes

Supertypes
trait Serializable
trait Product
trait Equals
class Object
trait Matchable
class Any
Show all

Attributes

Supertypes
class Object
trait Matchable
class Any
Self type

Attributes

Supertypes
class Object
trait Matchable
class Any
Known subtypes
trait Syntax extends AbstractSyntax

Attributes

Companion
object
Supertypes
trait AbstractSyntax
class Object
trait Matchable
class Any
object Syntax

Attributes

Companion
trait
Supertypes
class Object
trait Matchable
class Any
Self type
Syntax.type
case class TestCtxt(resolver: ContextSpecificResolver, extraImports: Seq[default.Import], testClass: ClassOrInterfaceDeclaration)

Attributes

Supertypes
trait Serializable
trait Product
trait Equals
class Object
trait Matchable
class Any
Show all
case class TypeParamCtxt(param: TypeParameter)

Attributes

Supertypes
trait Serializable
trait Product
trait Equals
class Object
trait Matchable
class Any
Show all
case object Unboxed extends BoxLevel

Attributes

Supertypes
trait Singleton
trait Product
trait Mirror
trait Serializable
trait Product
trait Equals
class BoxLevel
class Object
trait Matchable
class Any
Show all
Self type
Unboxed.type